==> django_simple_forums-1.3.0.tar.gz: django_simple_forums-1.3.0/test_settings.py <==
SECRET_KEY = 'psst'
SITE_ID = 1


DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': ':memory:',
        'USER': '',
        'PASSWORD': '',
        'HOST': '',
        'PORT': '',
    }
}


ROOT_URLCONF = 'simple_forums.urls'


TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': ['templates'],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
                'simple_forums.context_processors.installed_apps',
            ],
        },
    },
]


MIDDLEWARE_CLASSES = (
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
)


INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.admin',

    # Third party apps
    'adminsortable',

    # Custom Apps
    'simple_forums',
    'simple_forums.notifications',
)


AUTHENTICATION_BACKENDS = (
    "django.contrib.auth.backends.ModelBackend",
)


STATIC_ROOT = '/tmp/'  # Dummy
STATIC_URL = '/static/'


LOGIN_URL = '/'

EMAIL_BACKEND = 'django.core.mail.backends.console.EmailBackend'

==> django_simple_forums-1.3.5.tar.gz: django_simple_forums-1.3.5/test_settings.py <==
SECRET_KEY = 'psst'
SITE_ID = 1


DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': ':memory:',
        'USER': '',
        'PASSWORD': '',
        'HOST': '',
        'PORT': '',
    }
}


ROOT_URLCONF = 'test_urls'


TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': ['templates'],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
                'simple_forums.context_processors.installed_apps',
            ],
        },
    },
]


MIDDLEWARE_CLASSES = (
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
)


INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.admin',

    # Third party apps
    'adminsortable',

    # Custom Apps
    'simple_forums',
    'simple_forums.notifications',
)


AUTHENTICATION_BACKENDS = (
    "django.contrib.auth.backends.ModelBackend",
)


STATIC_ROOT = '/tmp/'  # Dummy
STATIC_URL = '/static/'


LOGIN_URL = '/'

EMAIL_BACKEND = 'django.core.mail.backends.console.EmailBackend'
